%% Spherical Harmonics rotation using general sampling points. 
% The code is meant to demonstrate the algorithm but is by no means
% efficient and in fact none of the possible pre-computations are used.

%% Perform setup 
pre();

% oversampling rate
os_rate = 1.5;
% choose method to generate set of sampling (supported are ('halton', 'spiral', 
% 'random', 'equator', 'semi-equator')
lambda_method = 'halton';

%% Perform precomputation and store result 
disp(sprintf('Starting precomputation for Algo. 1.'));

rot_data = {};
for( band = 1 : max_band)
 
  % number of samples, respecting the oversampling rate
  % in the case of critical sampling num_samples = 2*band+1;
  num_samples = shGetNumSamplesL( band, os_rate); 
  
  % generate sample points
  lambda_l = getPointsS2( num_samples, lambda_method);
  
  % compute the kernel matrix for the current band
  Q_l = shComputeKernelMatrix( band, lambda_l);
  % store condition number for post analysis
  cns(band) = cond(Q_l);
  
  % compute the change of basis matrix
  % if 
  if( 1.0 == os_rate)
    C_l = inv(Q_l);
  else 
    C_l = pinv(Q_l);
  end

  % store precompute results
  rot_data{band} = { C_l , lambda_l };
  
end
disp(sprintf('Finished precomputation for Algo. 1.'));
 
%% Compute rotation

% each band is rotated separately since the H_l are closed under rotation
disp(sprintf('Starting rotation using Algo. 1.'));
for( band = 1 : max_band)

  % retrieve precomputed data
  C_l = rot_data{band}{1};
  lambda_l = rot_data{band}{2};
  
  % rotate the sample points, note that the inverse rotation R^{-1} = R' 
  % is applied
  lambda_l_rot = rotatePointsS2( lambda_l, R');
  
  % evaluate signal in the current band at the rotated sample points
  % this yields the basis function coefficients with respect to the kernel
  % basis
  f_l = shEvalFunctionL( band, sh_coeffs, lambda_l_rot)';
  
  % compute rotated Spherical harmonics coefficients
  sh_coeffs_rot_band = transpose( C_l * f_l);
  
  % store rotated coefficients
  sh_coeffs_rot( : , shGetBandIdx( band)) = sh_coeffs_rot_band;
  
end

disp(sprintf('Finished rotation using Algo. 1.'));

%% Post processing
post();