%% Spherical Harmonics rotation using equi-latitude sampling points. 
% The code is meant to demonstrate the algorithm but is by no means
% efficient and in fact none of the possible pre-computations are used.

%% Perform setup 
pre();

% latitude for sample points
zeta = pi * 1/3; 
  
%% Perform rotation
disp(sprintf('Starting rotation using Algo. 2.'));

for( band = 1 : max_band)

  % generate sample points
  lambda_l = getPointsS2( 2*band+1, 'semi-equator', zeta);
    
  % rotate sample points
  lambda_l_rot = rotatePointsS2( lambda_l, R');

  % evaluate sub-band signal at rotated sample points
  f_l = shEvalFunctionL( band, sh_coeffs, lambda_l_rot);

  % perform FFT of f_l to obtain the Harmonic components
  h_l = fft(f_l');
  h_l_sin = imag(h_l');
  h_l_cos = real(h_l');

  % map harmonic coefficients to Spherical Harmonics coefficients

  % legendre polynomials
  p_lm = legendre( band, cos(zeta), 'sch');
  % condition number
  cns(band) = max(abs(p_lm)) / min(abs(p_lm));
  
  % apply Spherical Harmonics normalization which gives the complete
  % denominator
  p_lm = p_lm * 1/2 * sqrt((2*band+1) / (4*pi)) * (2*band+1);
  p_lm = repmat( p_lm', size( sh_coeffs, 1), 1);
  
  % recover the Spherical Harmonics coefficients by extracting the
  % sin(m \phi) and cos(m \phi) terms from the result of the FFT and then
  % dividing by the appropriate normalized Legendre polynomial term
  
  coeffs_sin = h_l_sin(:,1:band+1) ./ p_lm;
  coeffs_sin = coeffs_sin(:,end:-1:2);
  coeffs_cos = h_l_cos(:,1:band+1) ./ p_lm;
  coeffs_cos(:,1) = coeffs_cos(:,1) * 1/2;  

  sh_coeffs_rot_band = [coeffs_sin coeffs_cos];
  
  % store rotated coefficients
  sh_coeffs_rot( : , shGetBandIdx(band)) = sh_coeffs_rot_band;

end

disp(sprintf('Finished rotation using Algo. 1.'));

%% Post processing
post();
