%% Generate images for polyptych


%% Parameters

% maximum band of signal
band_max = 50;
% level for visualization
level_vis = 4;

% color for citites
cities_col = [0.9 0 0];
% cities_col_rot = [0 0.9 0];
cities_col_rot = [0.9 0.75 0];

% point size for cities
cities_size = 0.012;
% cities transparency
cities_transp = 0.5;

% rotation parameters
rot_axis = [-0.07935071  -0.077252  0.9938489];
rot_angle = -rad2deg(1.425822);

% position of camera
camera_pos =[-4.4277 16.5243 2.7095];
camera_pos_half = [-14.41792  9.363109  2.110839];

% base name for the generated images;
fname_img_base = './images/';
% resolution in dpo
res_str = '-r150';

% generate filename for signal
fname_signal = ['signals/world_sh_coeffs_L' num2str( band_max) '.mat'];
% load basis function coefficients 'sh_coeffs'
try 
  load( fname_signal);
catch
  error( 'Could not load file with signal representation.');
end

%% Load cities 
% The two different sets correspond to data from different sources and which 
% hence needs different processing
c_data_1 = readCitiesFile();
c_data_2 = readCitiesFile2();
% convert latitude / longitude representation to Cartesian coordinates
[c_data_xyz_1, c_data_spheric_1] = latlon2cartCities( c_data_1);
[c_data_xyz_2, c_data_spheric_2] = latlon2cartCities2( c_data_2);
% merge data sets
c_data_xyz = [c_data_xyz_1 ; c_data_xyz_2];
c_data_spheric = [c_data_spheric_1 ; c_data_spheric_2];

% rotated cities
R = getRotationMatrixAxisAngle( rot_axis, rot_angle);
temp = rotatePointsS2( c_data_spheric, R);
c_data_xyz_rot = s2_to_r3_list( temp);

%% Compute rotation

% corresponding rotation matrix
R = getRotationMatrixAxisAngle( rot_axis, rot_angle);

% basis function coefficients of the rotated signal
sh_coeffs_rot = sh_coeffs;

% rotate sample points
lambda = c_data_spheric;
lambda_rot = rotatePointsS2( lambda, R);

% do for all bands
for( band = 1 : band_max) 

  % compute the kernel matrix 
  % heavy oversampling is employed but this overcomes the bad conditioning
  % resulting from the clustering of the sample points
  Q_l = shComputeKernelMatrix( band, lambda_rot);

  % condition number (purely informative)
  cn = cond( Q_l);

  % change of basis matrix
  C_l = pinv(Q_l);

  % evaluate the band-signal for the current band at the rotated sample
  % points
  f_l = shEvalFunctionL( band, sh_coeffs, lambda)';

  % compute rotated Spherical harmonics coefficients
  sh_coeffs_rot_band = transpose(C_l * f_l);

  % store rotated coefficients
  sh_coeffs_rot(:,shGetBandIdx( band)) = sh_coeffs_rot_band;

  disp( sprintf( 'Finished rotation for band %i (cn = %f).', band, cn));

end

%% One: Unrotated 

% plot signal
h1 = figure;
plotUnitSphere();
shPlotFunction( band_max, sh_coeffs, level_vis, 0);

% set camera position
campos( camera_pos);

% save image file
fname_img_one = [fname_img_base '1' '.eps'];
print( h1, '-depsc', fname_img_one, res_str);


%% Two: Unrotated with cities

% plot signal
h2 = figure;
plotUnitSphere();
plotLocationSphere( c_data_xyz, cities_col, cities_transp, cities_size);
shPlotFunction( band_max, sh_coeffs, level_vis, 0);

% set camera position
campos( camera_pos);

% save image file
fname_img_two = [fname_img_base '2' '.eps'];
print( h2, '-depsc', fname_img_two, res_str);

%% Three: Semi-rotated with rotated and unrotated cities

% plot signal
h3 = figure;
plotUnitSphere();

% draw rotated and unrotated cities
plotLocationSphere( c_data_xyz, cities_col, cities_transp, cities_size);
plotLocationSphere( c_data_xyz_rot, cities_col_rot, cities_transp, cities_size);

% plot arc
plotArc( c_data_xyz, rot_axis, rot_angle, cities_col, cities_col_rot);

% plot background
shPlotFunction( band_max, sh_coeffs, level_vis, 0);

% set camera position
campos( camera_pos);

% save image file
fname_img_three = [fname_img_base '3' '.eps'];
print( h3, '-depsc', fname_img_three, res_str);


%% Four: Rotated with rotated cities

% plot signal
h4 = figure;
plotUnitSphere();
plotLocationSphere( c_data_xyz_rot, cities_col_rot, cities_transp, cities_size);
shPlotFunction( band_max, sh_coeffs_rot, level_vis, 0);

% set camera position
campos( camera_pos);

% save image file
fname_img_four = [fname_img_base '4' '.eps'];
print( h4, '-depsc', fname_img_four, res_str);


%% Four: Rotated without (rotated) cities

% plot signal
h5 = figure;
plotUnitSphere();
shPlotFunction( band_max, sh_coeffs_rot, level_vis, 0);

% set camera position
campos( camera_pos);

% save image file
fname_img_five = [fname_img_base '5' '.eps'];
print( h5, '-depsc', fname_img_five, res_str);



