%% Setup

% compatibility (on older Matlab versions warnings are generated)
warning( 'off');

% get functionality
addpath ./sh ./utility ./visualization ./cities

% parameters

% maximum band (note that the degree is max_band+1)
max_band = 20;
% variable to store condition number as a function of band
cns = zeros(1,max_band);
% variable to store error as a function of band
err = zeros(1,max_band);
% resolution parameter for visualization
level_vis = 4;

% get one random rotation (any rotation instead of #37 can be used too)
rand_rotations = getRandomRotation( 100);
R = rand_rotations{37};

% work around some matlab class problems
forest = getForestPlatonicSolid( 'octahedron', 1, 0);

%% Spherical Harmonics coefficients of the input signal
% load file with pre-computed Spherical Harmonics coefficients (to speed up
% computations), rows correspond to color channels; note that max_band has been
% chosen to match the length of coefficient vector which is loaded
% the coefficients can also be computed with shProjectSphericalMap() below 
% although the computations are rather slow; 
fname = ['signals/world_sh_coeffs_L' num2str(max_band) '.mat'];
% try to load coefficients, other (if the file does not exist) compute
try
  load( fname);
  disp(sprintf('Loaded basis function coefficients.'));
catch
  disp(sprintf('Computing basis function coefficients (slow).'));
  sh_coeffs = shProjectSphericalMap( max_band, 'signals/world.jpg');
  % store compute coefficients
  save( fname, 'sh_coeffs');
end

% basis function coefficient vector for the rotated signal
sh_coeffs_rot = sh_coeffs;

%% Visualize unrotated signal
disp(sprintf('Plotting unrotated signal.'));
shPlotFunction( max_band, sh_coeffs, level_vis);

