function row = shsComputeKernelMatrixRow( band, lambda)
%
% row = shComputeKernelMatrix( band, lambda)
%
% Compute one row of the kernel matrix Q for the specified band 
%
% @return row     row of the kernel matrix
% @param  band    band for which to compute the kernel matrix
% @param  lambda  sampling location (theta,phi)
    
  row = zeros(1,2*band+1);

  % Schmidt's normalized Legendre polynomial avoids that we have to deal
  % with the factorial terms in the normalization constant
  p_lm = legendre( band, cos(lambda(1)), 'sch');

  index = 1;
  for( m = -band : band)

    % the elements of the kernel matrix are given by the Spherical 
    % Harmonics function values
    row(index) = shEval( band, m, lambda(1), lambda(2), p_lm);
    index = index+1;

  end
  
end