function y = shEval( l, m, theta, phi, p_lm)
%
% y = shEval( l, m, theta, phi)
%
% Evaluate the (l,m)-th real Spherical Harmonic basis function at 
% (theta,phi)
% 
% @note (theta,phi) can be arrays
%
% @return sample  Function value of the (l,m)-th Spherical Harmonic at 
%                 (theta,phi)
% @param  l       Spherical Harmonic band
% @param  m       Harmonic within band l
% @param  theta   theta value(s) where to evaluate y_{l,m}
% @param  phi     phi  value(s) where to evaluate y_{l,m}
% @param  p_lm    precomputed values of the associated Legendre polynomials
%                 in the current band

  if( nargin < 5)
    % Schmidt's normalized Legendre polynomial avoids that we have to deal
    % with the factorial terms in the normalization constant
    p_lm = legendre( l, cos(theta), 'sch');
    if( 0 == l)
      p_lm = p_lm';
    end
  end

  % extract order and add normalization constant
  p = p_lm(abs(m)+1,:) * sqrt((2*l + 1) / (4*pi));

  % compute longitudal component
  if( 0 == m)
    y = p;
  elseif (m > 0)
    y = cos(m * phi)' .* p;
  else
    y = sin(abs(m) * phi)' .* p;
  end
  
end
