function f = shEvalFunction( band_max, sh_coeffs, omega) 
%
% f = shEvalFunction( band_max, sh_coeffs, omega) 
%
% Evaluate the function f represented by \a sh_coeffs at the point 
% omega = (theta,phi). The function f can have different channels which
% have to correspond to different rows of \a sh_coeffs. Multiple rows of omega
% correspond to multiple points where f is to be evaluated.
%
% @return f  function value(s) at omega
% @param  band_max  Maximal Spherical Harmonics band
% @param  sh_coeffs  Spherical Harmonics representation of the function f 
% @param  omega   Point(s) on S^2 where to evaluate f (theta / phi coords)

  % basic setup
  num_points = size( omega,1);
  num_channels = size( sh_coeffs, 1);
  f = zeros( num_channels, num_points);

  % perform reconstruction for all bands
  for( l = 0 : band_max)
    % for all Spherical Harmonics in the current bands
    for( m = -l : l)
      
      % some care is required with multiple color channels
      index = l * (l+1) + m + 1;
      f = f + repmat( sh_coeffs(:,index), 1, num_points) ...
             .* repmat( shEval( l, m, omega(:,1), omega(:,2)), num_channels, 1); 
    end
  end
  
end