function y_lm = shFunctionVals( band_max, omega) 
%
% f = shFunctionVals( band_max, sh_coeffs, omega) 
%
% Evaluate the Spherical Harmonics basis functions at the points \omega
%
% @return y_lm  Spherical Harmonics function values, band after band and
%               for each band from -m to m.
% @param  band_max  Maximal Spherical Harmonics band
% @param  omega   Point(s) on S^2 where to evaluate y_lm (theta / phi coords)

  % basic setup
  num_points = size( omega,1);
  y_lm = zeros( num_points, (band_max+1).^2);

  % perform for all bands
  for( l = 0 : band_max)
    % for all Spherical Harmonics in the current bands
    for( m = -l : l)      
      % Compute values of the current Spherical Harmonics basis function at
      % all points
      index = l*(l+1) + m+1;
      y_lm(:,index) = shEval( l, m, omega(:,1), omega(:,2)); 
    end
  end
  
end