function samples = shGenerateSamples( band_max, sqrt_num_samples)
%
% samples = shGenerateSamples( num_samples, band_max)
%
% Generate (sqrt_num_samples)^2 uniformly distributed samples on the sphere)
%
% @return  samples    Spherical Harmonics function values
% @param   band_max   maximum band for the sample values
% @param   sqrt_num_samples  square root of the number of samples       


  samples = {};

  inv_n = 1.0 / sqrt_num_samples;
  i = 1;
  
  for( a = 0 : (sqrt_num_samples-1))
    for( b = 0 : (sqrt_num_samples-1))    
  
      % generate random stratified sample
      x = (a + rand) * inv_n;
      y = (b + rand) * inv_n;
      
      % map samples to [0,pi] x [0,2pi]
      theta = 2 * acos( sqrt( 1 - x));
      phi = 2 * pi * y;
      
      % create a new sample and store its spherical (sph) and cartesian (vec)
      % coordinates
      sample.sph = [theta, phi, 1.0];
      sample.vec = [sin(theta) * cos(phi), sin(theta) * sin(phi), cos( theta)];
      
      coeffs = [];
      
      % Evaluate all basis functions under consideration for the current
      % sample
      
      % for all bands (from 0 to band_max-1)
      for( l = 0 : band_max)
        % for all basis functions within the band
        for( m = -l : l)
          
          index = l * (l+1) + m + 1;
          coeffs(index) = shEval( l, m, theta, phi);
          
        end  % end for all basis functions within a band
      end  % end for all bands

      % store function evaluations
      sample.coeffs = coeffs;
      % store the new sample
      samples{i} = sample;
      i = i + 1;
      
    end  % end a    
  end  % end b

end