function Rs = getRandomRotation( k)
%
% Rs = getRandomRotation( k)
%
% Generate k random rotations using an approach due to Arvo.
% (www.ics.uci.edu/~arvo/papers/RotationMat.ps))
%
% @return  Rs   Cell array of k rotation matrices.
% @param   k    Number of random rotations to generate.

  % generate random numbers
  r_vals_all = halton( k, 3);

  Rs = {};
  
  % generate the individual rotations
  for( i = 1 : k)
    
    r_vals = r_vals_all(i,:);
    
    % rotation around the Z axis
    R = eye(3);
    R(1,1) = cos( 2 * pi * r_vals(1));
    R(1,2) = sin( 2 * pi * r_vals(1));
    R(2,1) = -sin( 2 * pi * r_vals(1));    
    R(2,2) = cos( 2 * pi * r_vals(1));
    
    % Householder reflection
    v = [ cos(2*pi*r_vals(2)) * sqrt(r_vals(3)), ...
          sin(2*pi*r_vals(2)) * sqrt(r_vals(3)), ...
          sqrt( 1.0 - r_vals(3)) ];
    H = eye(3,3) - (2 * v' * v);
        
    M = -H * R;
    Rs{i} = M;
        
  end

end