function plotArc( verts, rot_axis, rot_angle, col1, col2, ...
                  offset_surface, line_width)
%
% plotArc( verts, col, offset_surface)
%
% Plot an arc as the the set of poitns 'verts' rotate 
% around the 'rot_axis' angle by 'rot_angle' degrees
%
% @param rot_axis   axis of rotation
% @param rot_angle  angle of rotation
% @param verts  [3x2] vertices of arc
% @param col  color of the arc (optional, default == blue)
% @param offset_surface  offset of arc w.r.t unit sphere 
%                        (optional, default == 1.001)

  % optional input arguments
  defval( 'offset_surface', 1.001);
  defval( 'line_width', 1.0);

  % normalize axis
  rot_axis = rot_axis/norm(rot_axis);

  % number of divisions to interpolate rotation
  rot_divisions = 15;

  for i = 0:rot_divisions
      angle = i * rot_angle/rot_divisions;
      R = getRotationMatrixAxisAngle(rot_axis,angle);
      verts_r = rotatePointsR3(verts,R);

      for j=1:size(verts_r,1)
          p = verts_r(j,:);
          % extrude slightly to sphere of radius 1+offset_surface
          p = p / norm(p) * offset_surface;
          Xcomp(i+1,j) = p(1);
          Ycomp(i+1,j) = p(2);
          Zcomp(i+1,j) = p(3);
      end
  end

  % draw the arc
  delta_c = [0 : 1/size(Xcomp,1) : 1];
  % do for all vertices
  for i = 1:size(verts_r,1)
    
    % for each vertex do for all segments
    for( j = 1 : size(Xcomp,1)-1)
      
      col = (1-delta_c(j)) * col1 + delta_c(j) * col2;
      
      fill3( Xcomp(j:j+1,i), Ycomp(j:j+1,i), Zcomp(j:j+1,i), [1 0 0], ...
             'EdgeAlpha', 0.15, 'EdgeColor', col);
    end
    
  end
    
end


