function plotLocationSphere( locs, col, transparency, loc_size, res_marker)
%
% plotLocationSphere( locs, col, transparency, loc_size, res_marker)
%
% Plot location using a cube as proxy geometry
%
% @param  locs  locations to plot
% @param  col   color for locations (default is [1 0 0])
% @param  transparency  transparency of proxy geometry  (default is 0.5)
% @param  loc_size  size to use for each location (default is 0.01)
% @param  res_marker  resolution of marker (default is 15)

  defval( 'loc_size', 0.01);
  defval( 'col', [1 0 0]);
  defval( 'transparency', 0.5);
  defval( 'res_marker', 15);
  
  % construct markers
  vertices = zeros( res_marker, 3);
  delta = 2*pi/res_marker;
  for( i = 1 : res_marker)
    delta_c = (i-1) * delta;
    vertices(i,:) = [loc_size * cos(delta_c), loc_size * sin(delta_c), 1.01];
  end
  
  % plot all locations
  for( i = 1 : size( locs, 1))
  
    ax = cross( locs(i,:), [0 0 1]);
    angle = acos( dot( locs(i,:), [0 0 1]));
    
    R = getRotationMatrixAxisAngle( ax, -rad_to_deg( angle));
    verts = transpose(R * vertices');
    
    fill3( verts(:,1), verts(:,2), verts(:,3), col, ...
           'FaceAlpha', transparency, 'EdgeColor', 'none', ...
           'FaceLighting', 'flat');
  
  end

end