function omega = spiralPoints(N)
%
% omega = spiralPoints( N)
%
% Compute spiral points on the sphere [Saff and Kuijklaars 1997].
%
% @return omega  spiral points in spherical (theta,phi) coordinates 
%                       (dimension is (N,2)) 
% @param N  cardinality of spiral points

  k = [1:N];
  h_k = -1 + 2*(k-1) / (N-1);

  % latitudes
  thetas = acos( h_k)';

  % longitudes
  phis = zeros( N, 1);
  N_sqrt = sqrt(N);
  % first and last points are zero
  for( i = 2 : (N-1))
    phis(i) = phis(i-1) + 3.6 / N_sqrt * 1 / (sqrt( 1 - h_k(i)^2));
    phis(i) = mod( phis(i), 2*pi);
  end 

  omega = [thetas , phis];

end

